package com.persagy.fm.common.constant;

/**
 * 正则表达式常量
 *
 * @author lixing
 * @version V1.0 2021/3/19 3:40 下午
 **/
public class RegexConstants {
    /**
     * 中文正则表达式
     */
    public static final String CH_REGEX = "[\u4e00-\u9fa5]";
    /**
     * 小写字母正则表达式
     */
    public static final String LOWERCASE_REGEX = "[a-z]";
    /**
     * 大写字母正则表达式
     */
    public static final String UPPERCASE_REGEX = "[A-Z]";

    /**
     * 数字正则表达式
     */
    public static final String NUM_REGEX = "[0-9]";
    /**
     * 允许的字符正则表达式
     */
    public static final String CHAR_REGEX = "['._#~]";

    public static final String EN_REGEX_EXPRESSION = LOWERCASE_REGEX + "|" + UPPERCASE_REGEX;
    public static final String EN_NUM_REGEX_EXPRESSION = EN_REGEX_EXPRESSION + "|" + NUM_REGEX;
    public static final String EN_NUM_CHAR_REGEX_EXPRESSION = EN_NUM_REGEX_EXPRESSION + "|" + CHAR_REGEX;
    public static final String NAME_REGEX_EXPRESSION = EN_NUM_CHAR_REGEX_EXPRESSION + "|" + CH_REGEX;
    public static final String TEXT_REGEX_EXPRESSION = CH_REGEX + "|" + EN_REGEX_EXPRESSION;

    /**
     * 允许的字符正则表达式报警信息
     */
    private static final String CHAR_REGEX_WARNING = " ' . _  #  ~  ";

    /**
     * 名称正则表达式
     * 支持中英文字符，数字，"._#~"
     */
    public static final String NAME_REGEX = "(" + NAME_REGEX_EXPRESSION + ")+";


    /**
     * 名称正则表达式报警信息
     */
    public static final String NAME_REGEX_WARNING = "仅可输入中文，字母，数字以及" + CHAR_REGEX_WARNING;

    /**
     * 文本正则表达式
     * 支持中英文字符
     */
    public static final String TEXT_REGEX = "(" + TEXT_REGEX_EXPRESSION + ")+";

    /**
     * 文本正则表达式报警信息
     */
    public static final String TEXT_REGEX_WARNING = "仅可输入中文，字母";

    /**
     * 英文正则表达式
     * 支持数字和字母
     */
    public static final String EN_NUM_REGEX = "(" + EN_NUM_REGEX_EXPRESSION + ")+";
    ;
    /**
     * 英文正则表达式报警信息
     */
    public static final String EN_NUM_REGEX_WARNING = "仅可输入字母，数字";

    /**
     * 英文、数字、字符正则表达式
     * 支持数字，字母，"._#~"
     */
    public static final String EN_NUM_CHAR_REGEX = "(" + EN_NUM_CHAR_REGEX_EXPRESSION + ")+";
    /**
     * 英文、数字、字符正则表达式报警信息
     */
    public static final String EN_NUM_CHAR_REGEX_WARNING = "仅可输入字母，数字以及" + CHAR_REGEX_WARNING;

    /**
     * 邮箱格式非法提示
     */
    public static final String EMAIL_REGEX_WARNING = "邮箱格式错误";

    /**
     * 身份证正则表达式
     */
    public static final String ID_CARD_REGEX = "( ^[1-9]\\d{5}(18|19|([23]\\d))\\d{2}((0[1-9])|" +
            "(10|11|12))(([0-2][1-9])|10|20|30|31)\\d{3}[0-9Xx]$)|" +
            "(^[1-9]\\d{5}\\d{2}((0[1-9])|(10|11|12))(([0-2][1-9])|10|20|30|31)\\d{2}$)";

    /**
     * 身份证非法提示
     */
    public static final String ID_CARD_REGEX_WARNING = "身份证格式错误";

    /**
     * 手机号正则表达式
     */
    public static final String PHONE_REGEX = "^((13[0-9])|(14[5|7])|(15([0-3]|[5-9]))|(18[0,5-9]))\\d{8}$";

    /**
     * 手机号非法提示
     */
    public static final String PHONE_REGEX_WARNING = "手机号格式错误";
}
